@@ -1,7 +1,7 @@
 package File::Touch;
-$File::Touch::VERSION = '0.11_01'; # TRIAL
+$File::Touch::VERSION = '0.11_02'; # TRIAL
 
-$File::Touch::VERSION = '0.1101';use 5.006;
+$File::Touch::VERSION = '0.1102';use 5.006;
 use warnings;
 use strict;
 
@@ -13,7 +13,7 @@ use Carp;
 use IO::File;
 use File::stat;
 use Fcntl;
-use Time::HiRes qw/ time utime /;
+use Time::HiRes 1.9764 qw/ time utime /;
 
 my $SYSOPEN_MODE = O_WRONLY|O_CREAT;
 eval {
